pub struct WebSocketChannel { /* private fields */ }Expand description
WebSocket channel implementation.
Unlike rest-hook (which pushes to an external endpoint), this channel broadcasts to clients that have connected to the server’s WebSocket endpoint and bound to a subscription via a binding token.
Implementations
Sourceimpl WebSocketChannel
impl WebSocketChannel
Sourcepub fn new(manager: Arc<WebSocketManager>) -> Self
pub fn new(manager: Arc<WebSocketManager>) -> Self
Creates a new WebSocket channel backed by the given manager.
Sourcepub fn manager(&self) -> &Arc<WebSocketManager>
pub fn manager(&self) -> &Arc<WebSocketManager>
Returns a reference to the underlying WebSocket manager.